@@ -2,13 +2,10 @@
 
 set -e
 
-if [ $# -ne 2 ]; then
-    echo "Usage: $0 <man-in> <inc-out>"
-    exit 1
-fi
+cd $(dirname $0)
 
-INPUT=$1
-OUTPUT=$2
+INPUT=../man/timg.1
+OUTPUT=timg-manpage.inc
 
 cat > "$OUTPUT" <<EOF
 /* created with create-manpage-inc.sh from $INPUT */
