@@ -15,12 +15,13 @@
 
 #include "framebuffer.h"
 
-#include <assert.h>
-#include <math.h>
-#include <stdio.h>
-#include <string.h>
 #include <strings.h>
 
+#include <cassert>
+#include <cstdint>
+#include <cstdio>
+#include <cstring>
+
 namespace timg {
 
 rgba_t rgba_t::ParseColor(const char *color) {
