@@ -16,11 +16,15 @@
 #ifndef JPEG_SOURCE_H_
 #define JPEG_SOURCE_H_
 
+#include <csignal>
 #include <memory>
+#include <string>
 
 #include "display-options.h"
+#include "framebuffer.h"
 #include "image-source.h"
-#include "terminal-canvas.h"
+#include "renderer.h"
+#include "timg-time.h"
 
 namespace timg {
 // Special case for JPEG decoding, as we can make use of decode+rough_scale
