@@ -26,6 +26,7 @@
 #include "buffered-write-sequencer.h"
 #include "display-options.h"
 #include "framebuffer.h"
+#include "term-query.h"
 #include "terminal-canvas.h"
 #include "thread-pool.h"
 #include "timg-time.h"
@@ -35,9 +36,12 @@
 namespace timg {
 
 SixelCanvas::SixelCanvas(BufferedWriteSequencer *ws, ThreadPool *thread_pool,
-                         bool required_cursor_placement_workaround,
-                         const DisplayOptions &opts)
-    : TerminalCanvas(ws), options_(opts), executor_(thread_pool) {
+                         const SixelOptions &sixel_options,
+                         const DisplayOptions &display_opts)
+    : TerminalCanvas(ws),
+      options_(display_opts),
+      full_cell_jump_(sixel_options.full_cell_jump),
+      executor_(thread_pool) {
     // Terminals might have different understanding where the curosr is placed
     // after an image is sent.
     // Apparently the original dec terminal placed it afterwards, but some
@@ -59,7 +63,7 @@ SixelCanvas::SixelCanvas(BufferedWriteSequencer *ws, ThreadPool *thread_pool,
     //   * https://vt100.net/dec/ek-vt382-rm-001.pdf#page=112
     //   * https://vt100.net/dec/ek-vt38t-ug-001.pdf#page=132
     // Plese send PR or issue if you know a less ugly way to deal with this.
-    if (!required_cursor_placement_workaround) {
+    if (!sixel_options.known_broken_cursor_placement) {
         //** The default way of doing things; works with most terminals.
         // works: konsole, mlterm, libvte-based, alacritty-sixel
         // breaks: xterm, wezterm
@@ -121,13 +125,12 @@ void SixelCanvas::Send(int x, int dy, const Framebuffer &fb_orig,
     // avoid capture whole 'this', so copy values locally
     const char *const cursor_handling_start = cursor_move_before_;
     const char *const cursor_handling_end   = cursor_move_after_;
-    std::function<OutBuffer()> encode_fun =
+    const std::function<OutBuffer()> encode_fun =
         [fb, buffer, offset, cursor_handling_start, cursor_handling_end]() {
             std::unique_ptr<const Framebuffer> auto_delete(fb);
 
             OutBuffer out(buffer, offset - buffer);
             WriteStringToOutBuffer(cursor_handling_start, &out);
-            WriteStringToOutBuffer("\033Pq", &out);  // Start sixel data
             sixel_output_t *sixel_out = nullptr;
             sixel_output_new(&sixel_out, WriteToOutBuffer, &out, nullptr);
 
@@ -144,7 +147,6 @@ void SixelCanvas::Send(int x, int dy, const Framebuffer &fb_orig,
             sixel_dither_destroy(sixel_dither);
             sixel_output_destroy(sixel_out);
 
-            WriteStringToOutBuffer("\033\\", &out);  // end sixel data
             WriteStringToOutBuffer(cursor_handling_end, &out);
             return out;
         };
@@ -155,11 +157,18 @@ void SixelCanvas::Send(int x, int dy, const Framebuffer &fb_orig,
 int SixelCanvas::cell_height_for_pixels(int pixels) const {
     assert(pixels <= 0);  // Currently only use-case
     pixels = -pixels;
-    // Unlike the other exact pixel canvases where we have to round to the
-    // next even cell_y_px, here we first need to round to the next even 6
-    // first.
-    return -((round_to_sixel(pixels) + options_.cell_y_px - 1) /
-             options_.cell_y_px);
+    if (full_cell_jump_) {
+        // https://github.com/hzeller/timg/issues/145#issuecomment-2579962760
+        // As DEC intended.
+        return -((round_to_sixel(pixels) - 6) / options_.cell_y_px + 1);
+    }
+    else {
+        // Unlike the other exact pixel canvases where we have to round to the
+        // next even cell_y_px, here we first need to round to the next even 6
+        // first.
+        return -((round_to_sixel(pixels) + options_.cell_y_px - 1) /
+                 options_.cell_y_px);
+    }
 }
 
 }  // namespace timg
