@@ -18,6 +18,11 @@
 // To compile this image viewer, first get image-magick development files
 // $ sudo apt-get install libgraphicsmagick++-dev
 
+#ifndef __STDC_FORMAT_MACROS
+#define __STDC_FORMAT_MACROS
+#endif
+#include <cinttypes>
+
 #include "buffered-write-sequencer.h"
 #include "display-options.h"
 #include "image-source.h"
@@ -28,39 +33,11 @@
 #include "terminal-canvas.h"
 #include "thread-pool.h"
 #include "timg-help.h"
+#include "timg-print-version.h"
 #include "timg-time.h"
-#include "timg-version.h"
 #include "unicode-block-canvas.h"
 #include "utils.h"
 
-#ifdef WITH_TIMG_SIXEL
-#include "sixel-canvas.h"
-#endif
-
-// To display version number
-#ifdef WITH_TIMG_OPENSLIDE_SUPPORT
-#include "openslide-source.h"
-#endif
-#ifdef WITH_TIMG_VIDEO
-#include "video-source.h"
-#endif
-#ifdef WITH_TIMG_GRPAPHICSMAGICK
-#include <Magick++.h>
-
-#include "graphics-magick-source.h"
-#endif
-#ifdef WITH_TIMG_SIXEL
-#include <sixel.h>
-#endif
-#ifdef WITH_TIMG_RSVG
-#include <cairo-version.h>
-#include <librsvg/rsvg.h>
-#endif
-#ifdef WITH_TIMG_POPPLER
-#include <cairo-version.h>
-#include <poppler.h>
-#endif
-
 // The following is to work around clang-tidy being confused and not
 // understanding that unistd.h indeed provides getopt(). So let's include
 // unistd.h for correctness, and then soothe clang-tidy with decls.
@@ -72,22 +49,31 @@ extern int optind;                             // NOLINT
 int getopt(int, char *const *, const char *);  // NOLINT
 }
 
+#ifdef WITH_TIMG_SIXEL
+#include "sixel-canvas.h"
+#endif
+
+#ifdef WITH_TIMG_GRPAPHICSMAGICK
+#include <Magick++.h>
+#endif
+
 #include <fcntl.h>
 #include <getopt.h>
-#include <libswscale/swscale.h>  // Only needed for version.
 #include <string.h>
 #include <strings.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 
+#include <algorithm>
 #include <cctype>
 #include <cerrno>
-#include <cinttypes>
+#include <chrono>
 #include <cmath>
 #include <csignal>
 #include <cstdint>
 #include <cstdio>
 #include <cstdlib>
+#include <deque>
 #include <fstream>
 #include <functional>
 #include <future>
@@ -100,10 +86,6 @@ int getopt(int, char *const *, const char *);  // NOLINT
 
 #include "framebuffer.h"
 
-#ifndef TIMG_VERSION
-#define TIMG_VERSION "(unknown)"
-#endif
-
 using timg::Duration;
 using timg::ImageSource;
 using timg::ITerm2GraphicsCanvas;
@@ -144,8 +126,8 @@ namespace timg {
 // Options configuring how images/videos are arranged and presented.
 struct PresentationOptions {
     // Rendering
-    Pixelation pixelation         = Pixelation::kNotChosen;
-    bool sixel_cursor_workaround  = false;
+    Pixelation pixelation = Pixelation::kNotChosen;
+    SixelOptions sixel_options{};
     bool tmux_workaround          = false;
     bool terminal_use_upper_block = false;
     bool use_256_color = false;  // For terminals that don't do 24 bit color
@@ -272,7 +254,7 @@ static int usage(const char *progname, ExitCode exit_code, int width,
         "\t--color8       : Choose 8 bit color mode for -ph or -pq\n"
         "\t--version      : Print detailed version including used libraries.\n"
         "\t                 (%s)\n"
-        "\t--verbose      : Print some stats after images shown.\n"
+        "\t--verbose      : Print some terminal query info and stats.\n"
         "\t-h             : Print this help and exit.\n"
         "\t--help         : Page through detailed manpage-like help and exit.\n"
 
@@ -296,7 +278,7 @@ static int usage(const char *progname, ExitCode exit_code, int width,
         "--frames\n",
         default_title ? "='" : "", default_title ? default_title : "",
         default_title ? "'" : "", width, height, kDefaultThreadCount,
-        TIMG_VERSION);
+        timg::timgVersion());
     return (int)exit_code;
 }
 
@@ -315,7 +297,6 @@ bool AppendToFileList(const std::string &filelist_file,
     const size_t last_slash = filelist_file.find_last_of('/');
     // Following works as expected if last_slash == npos (lsat_slash+1 == 0)
     const std::string prefix = filelist_file.substr(0, last_slash + 1);
-    std::string filename;
     for (std::string filename; std::getline(filelist_stream, filename); /**/) {
         if (filename.empty()) continue;
         if (consider_relative_to_filelist &&  //
@@ -351,7 +332,7 @@ static int PresentImages(LoadedImageSources *loaded_sources,
     case Pixelation::kSixelGraphics:
         compression_pool.reset(new ThreadPool(sequencer->max_queue_len() + 1));
         canvas.reset(new timg::SixelCanvas(sequencer, compression_pool.get(),
-                                           present.sixel_cursor_workaround,
+                                           present.sixel_options,
                                            display_opts));
         break;
 #endif
@@ -442,68 +423,6 @@ static const char *PixelationToString(Pixelation p) {
     return "";  // Make compiler happy.
 }
 
-// Print our version and various version numbers from our dependencies.
-static int PrintVersion(FILE *stream) {
-    fprintf(stream, "timg " TIMG_VERSION
-                    " <https://timg.sh/>\n"
-                    "Copyright (c) 2016..2024 Henner Zeller. "
-                    "This program is free software; license GPL 2.0.\n\n");
-#ifdef WITH_TIMG_GRPAPHICSMAGICK
-    fprintf(stream, "Image decoding %s\n",
-            timg::GraphicsMagickSource::VersionInfo());
-#endif
-#ifdef WITH_TIMG_OPENSLIDE_SUPPORT
-    fprintf(stream, "Openslide %s\n", timg::OpenSlideSource::VersionInfo());
-#endif
-#ifdef WITH_TIMG_JPEG
-    fprintf(stream, "Turbo JPEG\n");
-#endif
-#ifdef WITH_TIMG_RSVG
-    fprintf(stream, "librsvg %d.%d.%d + cairo %d.%d.%d\n",
-            LIBRSVG_MAJOR_VERSION, LIBRSVG_MINOR_VERSION, LIBRSVG_MICRO_VERSION,
-            CAIRO_VERSION_MAJOR, CAIRO_VERSION_MINOR, CAIRO_VERSION_MICRO);
-#endif
-#ifdef WITH_TIMG_POPPLER
-    fprintf(stream, "PDF rendering with poppler %s + cairo %d.%d.%d",
-            poppler_get_version(), CAIRO_VERSION_MAJOR, CAIRO_VERSION_MINOR,
-            CAIRO_VERSION_MICRO);
-#if not POPPLER_CHECK_VERSION(0, 88, 0)
-    // Too old versions of poppler don't have a bounding-box function
-    fprintf(stream, " (no --auto-crop)");
-#endif
-    fprintf(stream, "\n");
-#endif
-#ifdef WITH_TIMG_QOI
-    fprintf(stream, "QOI image loading\n");
-#endif
-#ifdef WITH_TIMG_STB
-    fprintf(stream,
-            "STB image loading; STB resize v"
-#ifdef STB_RESIZE_VERSION2
-            "2"
-#else
-            "1"
-#endif
-#ifdef WITH_TIMG_GRPAPHICSMAGICK
-            // If we have graphics magic, that will take images first,
-            // so STB will only really be called as fallback.
-            " (fallback)"
-#endif
-            "\n");
-#endif
-    fprintf(stream, "swscale %s\n", AV_STRINGIFY(LIBSWSCALE_VERSION));
-#ifdef WITH_TIMG_VIDEO
-    fprintf(stream, "Video decoding %s\n", timg::VideoSource::VersionInfo());
-#endif
-#ifdef WITH_TIMG_SIXEL
-    fprintf(stream, "Libsixel version %s\n", LIBSIXEL_VERSION);
-#endif
-    fprintf(stream,
-            "Half, quarter, iterm2, and kitty graphics output: "
-            "timg builtin.\n");
-    return 0;
-}
-
 int main(int argc, char *argv[]) {
 #ifdef WITH_TIMG_GRPAPHICSMAGICK
     Magick::InitializeMagick(*argv);
@@ -744,7 +663,7 @@ int main(int argc, char *argv[]) {
             break;
         case 'E': present.hide_cursor = false; break;
         case 'W': display_opts.fill_width = true; break;
-        case OPT_VERSION: return PrintVersion(stdout);
+        case OPT_VERSION: return timg::PrintComponentVersions(stdout);
         case OPT_TITLE:
             display_opts.show_title = !display_opts.show_title;
             if (optarg) display_opts.title_format = optarg;
@@ -798,6 +717,12 @@ int main(int argc, char *argv[]) {
         }
     }
 
+    timg::EnableTerminalQueryLogging(verbose);
+    if (verbose) {
+        // Called this earlier, but now that verbose enabled, again for logging
+        timg::DetermineTermSize();
+    }
+
     // -- A sieve of sanity checks and configuration refinement.
 
     if (geometry_width < 1 || geometry_height < 1) {
@@ -845,8 +770,8 @@ int main(int argc, char *argv[]) {
     if (present.pixelation == Pixelation::kNotChosen) {
         present.pixelation = Pixelation::kQuarterBlock;  // Good default.
         if (term.font_width_px > 0 && term.font_height_px > 0) {
-            auto graphics_info      = timg::QuerySupportedGraphicsProtocol();
-            present.tmux_workaround = graphics_info.in_tmux;
+            const auto graphics_info = timg::QuerySupportedGraphicsProtocol();
+            present.tmux_workaround  = graphics_info.in_tmux;
             switch (graphics_info.preferred_graphics) {
             case timg::GraphicsProtocol::kIterm2:
                 present.pixelation = Pixelation::kiTerm2Graphics;
@@ -856,9 +781,8 @@ int main(int argc, char *argv[]) {
                 break;
             case timg::GraphicsProtocol::kSixel:
 #ifdef WITH_TIMG_SIXEL
-                present.pixelation = Pixelation::kSixelGraphics;
-                present.sixel_cursor_workaround =
-                    graphics_info.known_broken_sixel_cursor_placement;
+                present.pixelation    = Pixelation::kSixelGraphics;
+                present.sixel_options = graphics_info.sixel;
 #else
                 present.pixelation = Pixelation::kQuarterBlock;
 #endif
@@ -876,9 +800,8 @@ int main(int argc, char *argv[]) {
     // If the user manually choose sixel, we still can't avoid a terminal
     // query, as we have to figure out if it has a broken cursor implementation.
     else if (present.pixelation == Pixelation::kSixelGraphics) {
-        auto graphics_info = timg::QuerySupportedGraphicsProtocol();
-        present.sixel_cursor_workaround =
-            graphics_info.known_broken_sixel_cursor_placement;
+        auto graphics_info    = timg::QuerySupportedGraphicsProtocol();
+        present.sixel_options = graphics_info.sixel;
     }
 #endif
 
@@ -992,7 +915,7 @@ int main(int argc, char *argv[]) {
 
     std::future<rgba_t> background_color_future;
     if (strcasecmp(bg_color.c_str(), "auto") == 0) {
-        std::function<rgba_t()> query_terminal = []() {
+        const std::function<rgba_t()> query_terminal = []() {
             return rgba_t::ParseColor(timg::QueryBackgroundColor());
         };
         // Finding the background color might take a while, so we query
@@ -1000,7 +923,7 @@ int main(int argc, char *argv[]) {
         // actually queries it.
         background_color_future     = pool->ExecAsync(query_terminal);
         display_opts.bgcolor_getter = [&background_color_future]() {
-            static rgba_t value = background_color_future.get();  // once
+            static const rgba_t value = background_color_future.get();  // once
             return value;
         };
     }
@@ -1024,7 +947,7 @@ int main(int argc, char *argv[]) {
     LoadedImageSources loaded_sources;
     for (const std::string &filename : filelist) {
         if (interrupt_received) break;
-        std::function<timg::ImageSource *()> f =
+        const std::function<timg::ImageSource *()> f =
             [filename, frame_offset, max_frames, do_img_loading, do_vid_loading,
              &display_opts, &exit_code, &errors_lock,
              &errors]() -> timg::ImageSource * {
@@ -1106,12 +1029,13 @@ int main(int argc, char *argv[]) {
                 PixelationToString(present.pixelation));
 #ifdef WITH_TIMG_SIXEL
         if (present.pixelation == Pixelation::kSixelGraphics) {
-            if (present.sixel_cursor_workaround) {
-                fprintf(stderr, " (with cursor placment workaround)");
-            }
-            else {
-                fprintf(stderr, " (with default cursor placement)");
-            }
+            fprintf(stderr, " (%s and %s)",
+                    present.sixel_options.known_broken_cursor_placement
+                        ? "with cursor placment workaround"
+                        : "with default cursor placement",
+                    present.sixel_options.full_cell_jump
+                        ? "full cursor cell jump"
+                        : "default cursor cell jump");
         }
 #endif
         if (present.pixelation == Pixelation::kKittyGraphics) {
@@ -1167,7 +1091,7 @@ int main(int argc, char *argv[]) {
 
         auto print_env = [](const char *env) {
             const char *value = getenv(env);
-            fprintf(stderr, " %-23s%s", env, value ? " = " : "   (not set)\n");
+            fprintf(stderr, " %-29s%s", env, value ? " = " : "   (not set)\n");
             if (value) fprintf(stderr, "\"%s\"\n", value);
         };
         fprintf(stderr, "Environment variables\n");
@@ -1176,6 +1100,7 @@ int main(int argc, char *argv[]) {
         print_env("TIMG_ALLOW_FRAME_SKIP");
         print_env("TIMG_USE_UPPER_BLOCK");
         print_env("TIMG_FONT_WIDTH_CORRECT");
+        print_env("TIMG_SIXEL_NEWLINE_WORKAROUND");
     }
 
     if (cell_size_unknown_in_pixel_mode && cell_size_warning_needed) {
@@ -1193,9 +1118,9 @@ int main(int argc, char *argv[]) {
     // transparency, the query might still be running. Wait a tiny bit so
     // that the terminal does not spill the result on the screen once we've
     // returned. If the result is already there, this will return immediately
-    if (background_color_future.valid())
+    if (background_color_future.valid()) {
         background_color_future.wait_for(std::chrono::milliseconds(200));
-
+    }
     free((void *)bg_pattern_color);
 
     // Deliberately leaking thread pool as we don't bother waiting for
