@@ -34,8 +34,16 @@ bool GetBoolenEnv(const char *env_name, bool default_value) {
 float GetFloatEnv(const char *env_var, float default_value) {
     const char *value = getenv(env_var);
     if (!value) return default_value;
-    char *err    = nullptr;
-    float result = strtof(value, &err);
+    char *err          = nullptr;
+    const float result = strtof(value, &err);
+    return (*err == '\0' ? result : default_value);
+}
+
+int GetIntEnv(const char *env_name, int default_value) {
+    const char *const value = getenv(env_name);
+    if (!value) return default_value;
+    char *err        = nullptr;
+    const int result = strtol(value, &err, 10);
     return (*err == '\0' ? result : default_value);
 }
 
